import { useEffect, useState } from "preact/hooks";
import { Modal } from "../components/modal.tsx";
import { LabelledHr } from "../components/labelledHr.tsx";
import { PacksList } from "../components/packsList.tsx";
import { PackInfo } from "../components/packInfo.tsx";

export const Editor = () => {
  const [packName, setPackName] = useState("");
  const [loading, setLoading] = useState(true);
  const [namespaces, setNamespaces] = useState<string[]>([]);

  useEffect(() => {
    document.title = "BearMetal Packer";
    fetch("/api/pack").then((res) => res.json()).then((json) => {
      setPackName(json.packName);
      setLoading(false);
    });
  }, []);

  const setPackNameThing = async (event: SubmitEvent) => {
    setLoading(true);
    const res = await fetch("/api/pack", {
      method: "POST",
      body: new FormData(event.target as HTMLFormElement),
    });

    if (res.status === 200) {
      document.title = packName;
      setPackName(packName);
    }
    setLoading(false);
  };

  if (!packName) {
    return (
      <Modal>
        {loading
          ? <p>Just a sec, trying to put the cats back in the bag.</p>
          : (
            <>
              <form
                method="POST"
                onSubmit={setPackNameThing}
              >
                <label class="w-full">Set pack name</label>
                <div class="flex gap-2">
                  <input type="text" name="packName" />
                  <button type="submit">Set</button>
                </div>
              </form>
              <LabelledHr>OR</LabelledHr>
              <PacksList setPackName={setPackName} />
            </>
          )}
      </Modal>
    );
  }

  return (
    <div class="flex h-full">
      <div class="w-1/4 p-4 bg-primary-600">
        <div class="text-center">
          <h1 class="text-2xl">BearMetalPacker</h1>
          <PackInfo packName={packName} />
        </div>
        <LabelledHr>Namespaces</LabelledHr>
        <div>
          <ul class="w-full">
            {namespaces.map((namespace) => (
              <li class="cursor-pointer even:bg-black/5" // onClick={() => setNamespace(namespace)}
              >
                {namespace}
              </li>
            ))}
          </ul>
        </div>
      </div>
    </div>
  );
};
